@@ -327,17 +327,17 @@ def get_mobile_device_presence(_wifi_devices_dict, _router_ip_address, _router_p
         wifi_key, wifi_bool = scan_wifi()
         if (_scan_for_device_type == "wifi") or (not bluetooth_bool):
             if _calling_software == "pir":
-                return wifi_key, wifi_bool
+                return wifi_key, _scan_for_device_type, wifi_bool
             elif _calling_software == "rha":
                 return wifi_bool
         elif (_scan_for_device_type == "bluetooth") or (not wifi_bool):
             if _calling_software == "pir":
-                return bluetooth_key, bluetooth_bool
+                return bluetooth_key, _scan_for_device_type, bluetooth_bool
             elif _calling_software == "rha":
                 return bluetooth_bool
         else:
             if _calling_software == "pir":
-                return None, False
+                return None, None, False
             elif _calling_software == "rha":
                 return False
 
